BeanNotFoundException class

Exception thrown when a required bean cannot be found

Inheritance

Constructors

BeanNotFoundException(Type type, {String? qualifier})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
qualifier String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited