Singleton class

Convenience annotation for singleton scope

Equivalent to @Scope(ScopeType.singleton)

Inheritance

Constructors

Singleton()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ScopeType
The scope type for the bean
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited