BeanNotFoundException class
Exception thrown when a required bean cannot be found
- Inheritance
-
- Object
- DireException
- BeanNotFoundException
Constructors
- BeanNotFoundException(Type type, {String? qualifier})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited