DireDiEntryPoint class
Marks a file as the entry point for DI code generation.
When this annotation is used, all DI components found across the entire project will be consolidated into a single generated registration file alongside this annotated class.
This ensures that registerGeneratedDependencies() only needs
to be called once from a single location.
Example:
@DireDiEntryPoint()
class AppModule {
// This file will receive the consolidated registration code
}
Constructors
- DireDiEntryPoint({String? outputFileName})
-
Creates a DI entry point annotation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputFileName → String?
-
The name of the generated file (optional).
If not provided, uses the default pattern:
{filename}.dire_di.dartfinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited