InjectionContext class
Injection context for managing bean creation and dependency resolution
Provides context information during the bean creation and injection process, including circular dependency detection and active profiles.
Constructors
Properties
-
activeProfiles
→ List<
String> -
Currently active profiles
final
- allowCircularDependencies → bool
-
Whether to allow circular dependencies
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ Map<
String, String> -
Environment properties
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkProperty(
String name, String expectedValue, {bool matchIfMissing = false}) → bool - Checks if a property matches the expected value
-
copyWith(
{List< String> ? activeProfiles, Map<String, String> ? properties, bool? allowCircularDependencies}) → InjectionContext - Creates a copy of this context with additional properties
-
getProperty(
String name) → String? - Gets a property value
-
isCreating(
Type type) → bool - Checks if a type is currently being created
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
popCreation(
Type type) → void - Pops a type from the creation stack
-
pushCreation(
Type type) → void - Pushes a type onto the creation stack
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited